@@ -68,13 +68,10 @@ QBluetoothDeviceDiscoveryAgentPrivate::QBluetoothDeviceDiscoveryAgentPrivate(
     deviceDiscoveryStartAttemptsLeft(deviceDiscoveryStartMaxAttempts),
     q_ptr(parent)
 {
-    QJniEnvironment env;
-    adapter = QJniObject::callStaticObjectMethod("android/bluetooth/BluetoothAdapter",
-                                                        "getDefaultAdapter",
-                                                        "()Landroid/bluetooth/BluetoothAdapter;");
-    if (!adapter.isValid()) {
+    adapter = getDefaultBluetoothAdapter();
+
+    if (!adapter.isValid())
         qCWarning(QT_BT_ANDROID) << "Device does not support Bluetooth";
-    }
 }
 
 QBluetoothDeviceDiscoveryAgentPrivate::~QBluetoothDeviceDiscoveryAgentPrivate()
@@ -241,6 +238,8 @@ void QBluetoothDeviceDiscoveryAgentPrivate::start(QBluetoothDeviceDiscoveryAgent
         QObject::connect(receiver, SIGNAL(finished()), this, SLOT(processSdpDiscoveryFinished()));
     }
 
+    lastError = QBluetoothDeviceDiscoveryAgent::NoError;
+    errorString.clear();
     discoveredDevices.clear();
 
     // by arbitrary definition we run classic search first
@@ -447,7 +446,9 @@ void QBluetoothDeviceDiscoveryAgentPrivate::startLowEnergyScan()
     m_active = BtleScanActive;
 
     if (!leScanner.isValid()) {
-        leScanner = QJniObject("org/qtproject/qt/android/bluetooth/QtBluetoothLE");
+        leScanner = QJniObject("org/qtproject/qt/android/bluetooth/QtBluetoothLE",
+                               "(Landroid/content/Context;)V",
+                               QNativeInterface::QAndroidApplication::context());
         if (!leScanner.isValid()) {
             qCWarning(QT_BT_ANDROID) << "Cannot load BTLE device scan class";
             m_active = NoScanActive;
